Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/mono/libgit2sharp.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authornulltoken <emeric.fermas@gmail.com>2012-04-16 23:46:23 +0400
committernulltoken <emeric.fermas@gmail.com>2012-04-28 05:32:15 +0400
commitbabf77dda5cf70d3d80fd99961e53e085d9a767e (patch)
tree825309921d6b946fad821d6eed5bbb1f2c8cbf65 /LibGit2Sharp/TreeEntry.cs
parent0787252beb87eb9e7a707e6c414c533b9f8bc38f (diff)
Deploy usage of the Mode enum
Diffstat (limited to 'LibGit2Sharp/TreeEntry.cs')
-rw-r--r--LibGit2Sharp/TreeEntry.cs7
1 files changed, 3 insertions, 4 deletions
diff --git a/LibGit2Sharp/TreeEntry.cs b/LibGit2Sharp/TreeEntry.cs
index 4957cf63..6e3ca656 100644
--- a/LibGit2Sharp/TreeEntry.cs
+++ b/LibGit2Sharp/TreeEntry.cs
@@ -1,5 +1,4 @@
using System;
-using System.Runtime.InteropServices;
using LibGit2Sharp.Core;
using LibGit2Sharp.Core.Compat;
using LibGit2Sharp.Core.Handles;
@@ -28,15 +27,15 @@ namespace LibGit2Sharp
Type = NativeMethods.git_tree_entry_type(obj);
target = new Lazy<GitObject>(RetrieveTreeEntryTarget);
- Attributes = (int)NativeMethods.git_tree_entry_attributes(obj);
+ Mode = (Mode)NativeMethods.git_tree_entry_attributes(obj);
Name = NativeMethods.git_tree_entry_name(obj);
path = new Lazy<string>(() => System.IO.Path.Combine(parentPath.Native, Name));
}
/// <summary>
/// Gets the UNIX file attributes.
/// </summary>
- public int Attributes { get; private set; }
+ public Mode Mode { get; private set; }
/// <summary>
/// Gets the filename.
@@ -28,15 +27,15 @@ namespace LibGit2Sharp
}
/// <summary>
- /// Gets the UNIX file attributes.
+ /// Gets the file mode.
/// </summary>